
/*  xmms_insert
 *  Copyright (C) 2001    David T. McWherter
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public Licensse as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#include <string.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <errno.h>
#include <stdio.h>
#include <xmms/xmmsctrl.h>

static const char * ltrim ( const char * str ) { 
	while ( *str && isspace(*str) ) 
		++str;
	return str;
}

static int is_absolute ( const char * str ) { 
	const char * strp = ltrim( str );
	return ( *strp == '/' || *strp == '~' );
}

static const char * progname = "xmms_insert";

int main ( int argc, char * argv[] ) { 
	char cwd[PATH_MAX] = "";
	gint session = 0;
	gint pos;
	int i;

	if ( argc > 0 ) 
		progname = argv[0];
	
	if ( argc < 2 ) { 
		fprintf( stderr, "%s: Insert into xmms playlist immediately after current song\n", progname );
		exit(1);
	}

	if ( getcwd(cwd, sizeof(cwd)) == 0 ) {
		perror("getcwd");
		exit(2);
	}
	
	pos = xmms_remote_get_playlist_pos(session);
	for ( i = 1; i < argc; ++i ) { 
		char fullpath[PATH_MAX] = "";
		const char * path = ltrim( argv[i] );
		if ( strlen(path) > 0 ) { 
			struct stat statbuf;
			if ( stat(path, &statbuf) == ENOENT ) { 
				/** We didn't get a file, see if XMMS knows what to do */
				xmms_remote_playlist_ins_url_string( session, path, pos+1 );
			} else { 
				/** We got a file, absolutify it, if we can */
				if ( is_absolute(path) )  {
					strncat( fullpath, path, sizeof(fullpath) );
				} else { 
					strncat( fullpath, cwd, sizeof(fullpath) );
					strncat( fullpath, "/", sizeof(fullpath) );
					strncat( fullpath, path, sizeof(fullpath) );
				}
				xmms_remote_playlist_ins_url_string( session, fullpath, pos+1 );
			}
		}
	}
	return 0;
}


